@@ -1,23 +1,22 @@
 package Net::DNS::RR::NXT;
 
-# $Id: NXT.pm 260 2005-03-31 11:44:39Z olaf $
+# $Id: NXT.pm,v 1.2 2002/06/04 12:14:18 olaf Exp $
 
 use strict;
 use vars qw(@ISA $VERSION);
 use Carp;
 
-use Net::DNS;
+use Net::DNS::SEC;
 use Net::DNS::Packet;
 
 
 use Carp;
 
 @ISA = qw(Net::DNS::RR);
-$VERSION = do { my @r=(q$Revision: 260 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
+$VERSION = do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
 
 sub new {
     my ($class, $self, $data, $offset) = @_;
-    carp "The NXT RR is depricated as of RFC3755, please refrain from using this record";
     
     if ($self->{"rdlength"} > 0) {
 	my($nxtdname,$nxtoffset) = 
@@ -33,22 +32,21 @@ sub new {
 	$self->{"typelist"} = join " " 
 	    ,  _typebm2typestr($typebm);
     }
+    
     return bless $self, $class;
 }
 
 sub new_from_string {
     my ($class, $self, $string) = @_;
-    carp "The NXT RR is depricated as of RFC3755";
     if ($string) {
 	$string =~ tr/()//d;
 	$string =~ s/;.*$//mg;
-	$string =~ s/\n//mg;
-	my ($nxtdname,$nxtstr) = 
-	    $string =~ /^\s*(\S+)\s+(.*)/;
-	my @nxttypes = split /\s+/ , $nxtstr;       # everything after last match...
+	my ($nxtdname) = 
+	    $string =~ /^\s*(\S+)\s+/;
+	my @nxttypes = split /\s+/ , $';       # everything after last match...
 	
 	$self->{"nxtdname"}= lc($nxtdname) ;
-	$self->{"typelist"}= join " " , sort @nxttypes ;
+	$self->{"typelist"}= join " " ,@nxttypes ;
 	$self->{"typebm"}=_typestr2typebm(@nxttypes);
 	
     }
@@ -56,20 +54,6 @@ sub new_from_string {
 }
 
 
-
-
-#sub is_optin {
-#    my $self =shift;
-#    return 1 if $self->{"typelist"}!~/NXT/;
-#    0;
-#}
-
-#sub set_optin {
-#    my $self =shift;
-#    $self->{"typelist"}=~s/NXT//;
-#    1;
-#}
-
 sub rdatastr {
 	my $self = shift;
 	my $rdatastr;
@@ -125,12 +109,11 @@ sub _typestr2typebm {
 	$typebitarray[$Net::DNS::typesbyname{uc($typelist[$i])}]=1;
     }
     
-    my $finalsize=0;
-    {
+    my $finalsize;
+    if ( @typebitarray % 4){
 	use integer;
 	$finalsize = 8 * ((@typebitarray / 8)  + 1);
     }
-
     for (my $i=0;$i< $finalsize; $i++){
 	$typebitarray[$i]=0 if ! defined $typebitarray[$i];
     }
@@ -154,7 +137,7 @@ sub _typebm2typestr {
 	    ($typebm[$foo] eq "1");
     }
 
-    return sort @typelist;
+    return @typelist;
 }
 
 
@@ -167,17 +150,12 @@ Net::DNS::RR::NXT - DNS NXT resource record
 
 =head1 SYNOPSIS
 
-C<use Net::DNS::RR;>
+C<use Net::DNS::RR>;
 
 =head1 DESCRIPTION
 
-B<NOTE: THE NXT RR has been deprecated! Use NSEC instead.>
-
-
-
 Class for DNS Address (NXT) resource records.
 
-
 =head1 METHODS
 
 =head2 nxtdname
@@ -206,7 +184,7 @@ on daily basis.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2005  RIPE NCC.  Author Olaf M. Kolkman <olaf@net-dns.org>
+Copyright (c) 2001  RIPE NCC.  Author Olaf M. Kolkman <net-dns-sec@ripe.net>
 
 All Rights Reserved
 
@@ -228,14 +206,12 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 Based on, and contains, code by Copyright (c) 1997 Michael Fuhr.
 
-=head1 SEE ALSO
 
-L<http://www.net-dns.org/> 
+
+=head1 SEE ALSO
 
 L<perl(1)>, L<Net::DNS>, L<Net::DNS::Resolver>, L<Net::DNS::Packet>,
 L<Net::DNS::Header>, L<Net::DNS::Question>, L<Net::DNS::RR>,
 RFC 2435 Section 5
 
-
-
 =cut
